pymodaq_plugins_keithley (Keithley)
###################################

.. image:: https://img.shields.io/pypi/v/pymodaq_plugins_keithley .svg
   :target: https://pypi.org/project/pymodaq_plugins_physical_measurements/
   :alt: Latest Version

.. image:: https://readthedocs.org/projects/pymodaq/badge/?version=latest
   :target: https://pymodaq.readthedocs.io/en/stable/?badge=latest
   :alt: Documentation Status

.. image:: https://github.com/PyMoDAQ/pymodaq_plugins_keithley /workflows/Upload%20Python%20Package/badge.svg
    :target: https://github.com/PyMoDAQ/pymodaq_plugins_keithley

'Set of PyMoDAQ plugins for various physical measurements from keithley'


Authors
=======

* Sebastien J. Weber
* Sébastien Guerrero  (sebastien.guerrero@insa-lyon.fr)

Contributors
============

* Nicolas Bruyant
* Loïc Guilmard (loic.guilmard@insa-lyon.fr)
* Anthony Buthod (anthony.buthod@insa-lyon.fr)

Instruments
===========
Below is the list of instruments included in this plugin


Actuator
++++++++

* **Keithley2400**: Sourcemeter Keithley  2400 (using pymeasure intermediate package)

Viewer0D
++++++++

* **Keithley_Pico**: Pico-Amperemeter Keithley 648X Series, 6430 and 6514
* **Keithley2110**: Multimeter Keithley  2110
* **Keithley27XX**: Keithley 27XX Multimeter/Switch System using switching modules from the 7700 series.